@@ -104,7 +104,7 @@ ImapResource::ImapResource( const QString &id )
                                   QString::fromLatin1( "InstanceCounters/%1/InstanceCounter" ).arg( agentType ),
                                   -1 ).toInt();
 
-    if ( instanceCounter>0 ) {
+    if ( instanceCounter > 0 ) {
       setName( i18n( "IMAP Account %1", instanceCounter ) );
     } else {
       setName( i18n( "IMAP Account" ) );
@@ -170,22 +170,23 @@ bool ImapResource::isFastSyncEnabled() const
 
 int ImapResource::configureDialog( WId windowId )
 {
-  SetupServer dlg( this, windowId );
-  KWindowSystem::setMainWindow( &dlg, windowId );
+  QPointer<SetupServer> dlg = new SetupServer( this, windowId );
+  KWindowSystem::setMainWindow( dlg, windowId );
 
-  dlg.setWindowIcon( KIcon( "network-server" ) );
-  dlg.exec();
-  if ( dlg.shouldClearCache() ) {
+  dlg->setWindowIcon( KIcon( "network-server" ) );
+  dlg->exec();
+  if ( dlg->shouldClearCache() ) {
     clearCache();
   }
 
-  int result = dlg.result();
+  int result = dlg->result();
+  delete dlg;
 
-  if ( result==QDialog::Accepted ) {
+  if ( result == QDialog::Accepted ) {
     Settings::self()->writeConfig();
   }
 
-  return dlg.result();
+  return result;
 }
 
 void ImapResource::configure( WId windowId )
@@ -228,8 +229,8 @@ int ImapResource::configureSubscription()
   if ( password.isEmpty() )
      return -1;
 
-  SubscriptionDialog *subscriptions = new SubscriptionDialog( 0, SubscriptionDialog::AllowToEnableSubscription );
-  subscriptions->setCaption( i18n( "Serverside Subscription..." ) );
+  QPointer<SubscriptionDialog> subscriptions = new SubscriptionDialog( 0, SubscriptionDialog::AllowToEnableSubscription );
+  subscriptions->setCaption( i18nc( "@title:window", "Serverside Subscription" ) );
   subscriptions->setWindowIcon( KIcon( "network-server" ) );
   subscriptions->connectAccount( *m_pool->account(), password );
   subscriptions->setSubscriptionEnabled( Settings::self()->subscriptionEnabled() );
@@ -293,6 +294,9 @@ void ImapResource::onConnectionLost( KIMAP::Session */*session*/ )
 
 bool ImapResource::retrieveItem( const Akonadi::Item &item, const QSet<QByteArray> &parts )
 {
+  // The collection name is empty here...
+  //emit status( AgentBase::Running, i18nc( "@info:status", "Retrieving item in '%1'", item.parentCollection().name() ) );
+
   ResourceStateInterface::Ptr state = ::ResourceState::createRetrieveItemState( this, item, parts );
   RetrieveItemTask *task = new RetrieveItemTask( state, this );
   task->start( m_pool );
@@ -302,6 +306,8 @@ bool ImapResource::retrieveItem( const Akonadi::Item &item, const QSet<QByteArra
 
 void ImapResource::itemAdded( const Item &item, const Collection &collection )
 {
+  emit status( AgentBase::Running, i18nc( "@info:status", "Adding item in '%1'", collection.name() ) );
+
   ResourceStateInterface::Ptr state = ::ResourceState::createAddItemState( this, item, collection );
   AddItemTask *task = new AddItemTask( state, this );
   task->start( m_pool );
@@ -310,6 +316,8 @@ void ImapResource::itemAdded( const Item &item, const Collection &collection )
 
 void ImapResource::itemChanged( const Item &item, const QSet<QByteArray> &parts )
 {
+  emit status( AgentBase::Running, i18nc( "@info:status", "Updating item in '%1'", item.parentCollection().name() ) );
+
   ResourceStateInterface::Ptr state = ::ResourceState::createChangeItemState( this, item, parts );
   ChangeItemTask *task = new ChangeItemTask( state, this );
   task->start( m_pool );
@@ -327,6 +335,8 @@ void ImapResource::itemRemoved( const Akonadi::Item &item )
     return;
   }
 
+  emit status( AgentBase::Running, i18nc( "@info:status", "Removing item from '%1'", item.parentCollection().name() ) );
+
   RemoveItemTask *task = new RemoveItemTask( state, this );
   task->start( m_pool );
   queueTask( task );
@@ -337,6 +347,8 @@ void ImapResource::itemMoved( const Akonadi::Item &item, const Akonadi::Collecti
 {
   Q_ASSERT( item.parentCollection() == destination ); // should have been set by the server
 
+  emit status( AgentBase::Running, i18nc( "@info:status", "Moving item from '%1' to '%2'", source.name(), destination.name() ) );
+
   ResourceStateInterface::Ptr state = ::ResourceState::createMoveItemState( this, item, source, destination );
   MoveItemTask *task = new MoveItemTask( state, this );
   task->start( m_pool );
@@ -349,6 +361,8 @@ void ImapResource::itemMoved( const Akonadi::Item &item, const Akonadi::Collecti
 
 void ImapResource::retrieveCollections()
 {
+  emit status( AgentBase::Running, i18nc( "@info:status", "Retrieving folders" ) );
+
   ResourceStateInterface::Ptr state = ::ResourceState::createRetrieveCollectionsState( this );
   RetrieveCollectionsTask *task = new RetrieveCollectionsTask( state, this );
   task->start( m_pool );
@@ -357,6 +371,8 @@ void ImapResource::retrieveCollections()
 
 void ImapResource::retrieveCollectionAttributes( const Akonadi::Collection &collection )
 {
+  emit status( AgentBase::Running, i18nc( "@info:status", "Retrieving folder attributes for '%1'", collection.name() ) );
+
   ResourceStateInterface::Ptr state = ::ResourceState::createRetrieveCollectionMetadataState( this, collection );
 
   RetrieveCollectionMetadataTask *task = new RetrieveCollectionMetadataTask( state, this );
@@ -368,6 +384,7 @@ void ImapResource::retrieveCollectionAttributes( const Akonadi::Collection &coll
 void ImapResource::triggerCollectionExtraInfoJobs( const QVariant &collectionVariant )
 {
   const Collection collection( collectionVariant.value<Collection>() );
+  emit status( AgentBase::Running, i18nc( "@info:status", "Retrieving extra folder information for '%1'", collection.name() ) );
   ResourceStateInterface::Ptr state = ::ResourceState::createRetrieveCollectionMetadataState( this, collection );
 
   RetrieveCollectionMetadataTask *task = new RetrieveCollectionMetadataTask( state, this );
@@ -399,6 +416,7 @@ void ImapResource::retrieveItems( const Collection &col )
 
 void ImapResource::collectionAdded( const Collection & collection, const Collection &parent )
 {
+  emit status( AgentBase::Running, i18nc( "@info:status", "Creating folder '%1'", collection.name() ) );
   ResourceStateInterface::Ptr state = ::ResourceState::createAddCollectionState( this, collection, parent );
   AddCollectionTask *task = new AddCollectionTask( state, this );
   task->start( m_pool );
@@ -407,6 +425,7 @@ void ImapResource::collectionAdded( const Collection & collection, const Collect
 
 void ImapResource::collectionChanged( const Collection &collection, const QSet<QByteArray> &parts )
 {
+  emit status( AgentBase::Running, i18nc( "@info:status", "Updating folder '%1'", collection.name() ) );
   ResourceStateInterface::Ptr state = ::ResourceState::createChangeCollectionState( this, collection, parts );
   ChangeCollectionTask *task = new ChangeCollectionTask( state, this );
   task->start( m_pool );
@@ -423,6 +442,7 @@ void ImapResource::collectionRemoved( const Collection &collection )
     changeProcessed();
     return;
   }
+  emit status( AgentBase::Running, i18nc( "@info:status", "Removing folder '%1'", collection.name() ) );
 
   RemoveCollectionRecursiveTask *task = new RemoveCollectionRecursiveTask( state, this );
   task->start( m_pool );
@@ -433,6 +453,8 @@ void ImapResource::collectionMoved( const Akonadi::Collection &collection, const
                                     const Akonadi::Collection &destination )
 {
   ResourceStateInterface::Ptr state = ::ResourceState::createMoveCollectionState( this, collection, source, destination );
+  emit status( AgentBase::Running, i18nc( "@info:status", "Moving folder '%1' from '%2' to '%3'",
+        collection.name(), source.name(), destination.name() ) );
   MoveCollectionTask *task = new MoveCollectionTask( state, this );
   task->start( m_pool );
   queueTask( task );
